==> haskell-servant-0.18.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant
version:              0.18.3
visibility:           public
id:                   servant-0.18.3-Ls4uW1KehaeLa70NK0aF5V
key:                  servant-0.18.3-Ls4uW1KehaeLa70NK0aF5V
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  16dd6ab139a82451b61d361498850292
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeLevel Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.0.1/site-local/servant-0.18.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/servant-0.18.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/servant-0.18.3
hs-libraries:         HSservant-0.18.3-Ls4uW1KehaeLa70NK0aF5V
depends:
    QuickCheck-2.14.2-Hi2DusSU1aNLBaKmssS2cn
    aeson-1.5.6.0-6DdSUx8dbuIIjP00Zg5a6S
    attoparsec-0.14.1-2NPvvgp5QbjKeCRmapAgpC base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    bifunctors-5.5.11-3MgHowlkzBNDa84Pzdaw4w bytestring-0.10.12.1
    case-insensitive-1.2.1.0-J1gQtd73c5YHY9YtfdlefR deepseq-1.4.5.0
    http-api-data-0.4.3-7amDLsGwUtcJkmhdVs0fyH
    http-media-0.8.0.0-7FCvEqaHusr3Wsb2XQBRDO
    http-types-0.12.3-5xSWCbzPZMJ3FKkHNvWW2m
    mmorph-1.2.0-Ajh0k0abpSlDb3Q6HDcBvb mtl-2.2.2
    network-uri-2.6.4.1-32se5oU1b9O36LNwPHSlHj
    singleton-bool-0.1.6-HMd8b5o9srcKE3b88hhcU5
    sop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr
    string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 text-1.2.4.1
    transformers-0.5.6.2 vault-0.3.1.5-5rFIghOpfR0F7oBrhbzq8P

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.18.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant
version:              0.18.3
visibility:           public
id:                   servant-0.18.3-1XqwkckqzIP8FdXKUwOeuS
key:                  servant-0.18.3-1XqwkckqzIP8FdXKUwOeuS
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them

    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  f325d68fa9fcd2e47f751ad148461ea9
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.HttpVersion
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Status Servant.API.Stream
    Servant.API.Sub Servant.API.TypeLevel Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.0.1/site-local/servant-0.18.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/servant-0.18.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/servant-0.18.3
hs-libraries:         HSservant-0.18.3-1XqwkckqzIP8FdXKUwOeuS
depends:
    QuickCheck-2.14.2-3f9Gw3UEGqTK3AyHIcW3dz
    aeson-1.5.6.0-FZsVpvEwT8z4bK1D26EwAs
    attoparsec-0.14.1-B8P567zH1pOF107V9enGUK base-4.15.0.0
    base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    bifunctors-5.5.11-6LpscOqvpXFF7to3ER7bDY bytestring-0.10.12.1
    case-insensitive-1.2.1.0-810KinvQcYx7xuCoSIHpwY deepseq-1.4.5.0
    http-api-data-0.4.3-5n7QBqX81Tk55DcuInPgjy
    http-media-0.8.0.0-FhKzgr2UAXdBnqKQF0J9O8
    http-types-0.12.3-J3pS8fDTy4j62mHquuNqa5
    mmorph-1.2.0-Ajh0k0abpSlDb3Q6HDcBvb mtl-2.2.2
    network-uri-2.6.4.1-BnEimF9gukhI4cE0Ew2RUr
    singleton-bool-0.1.6-HMd8b5o9srcKE3b88hhcU5
    sop-core-0.5.0.1-AXbFIEygwaRHSMwVmZvzfr
    string-conversions-0.4.0.1-FEX4HQj6e7k5a1sJJv8Hmk
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 text-1.2.4.1
    transformers-0.5.6.2 vault-0.3.1.5-LDTtIWpWoGTEQp4jnlvcxt

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
